@@ -377,6 +377,8 @@ Warning: dim_name_map may be changed in place
         hasbounds = self.hasbounds
         if hasbounds != other._hasbounds:
             # add traceback
+            if traceback:
+                print 'one has bounds, teh other not'
             return False
 
         direction0 = self.direction()
@@ -387,13 +389,19 @@ Warning: dim_name_map may be changed in place
 
         # Compare the data arrays
         if not super(BoundedVariable, self)._equivalent_data(
-                other, rtol=rtol, atol=atol):
+                other, rtol=rtol, atol=atol, traceback=True):            
+            if traceback:
+                # add traceback
+                print 'non equivaelnt data arrays'
             return False
 
         if hasbounds:
             # Both variables have bounds
             if not self.bounds._equivalent_data(other.bounds, rtol=rtol,
                                                 atol=atol):
+                if traceback:
+                    # add traceback
+                    print 'non equivaelnt bounds data'
                 return False
         #--- End: if
 
@@ -1721,7 +1729,7 @@ Insert cell bounds.
         self_units = self.Units
         if units and not units.equivalent(self_units):
             raise ValueError(
-"Can't set bounds: Incompatible units: {0!r} (not equivalent to {1!r})".format(
+"Can't set bounds: Incompatible units: Bounds units {0!r} are not equivalent to {1!r}".format(
     bounds.Units, self.Units))
             
         bounds.Units = self_units
