@@ -552,51 +552,6 @@ Return a string containing a full description of the coordinate.
         return super(Coordinate, self).dump(
             display=display, omit=omit, field=field, key=key,
              _level=_level, _title=_title)
-
-#
-#
-#
-#        if _title is None:
-#            if self.isdimension:
-#                x = 'Dimension Coordinate'
-#            elif self.isauxiliary:
-#                x = 'Auxiliary Coordinate'
-#            else:
-#                x = 'Coordinate'
-#            string = ['{0}{1}: {2}'.format(indent0, x, self.name(''))]
-#        else:
-#            string = [indent0 + _title]
-#
-#        if field:
-#            x = ['%s(%d)' % (field.axis_name(axis), field.axis_size(axis))
-#                 for axis in field.item_axes(key)]
-#            string.append('%sData(%s) = %s' % (indent1, ', '.join(x),
-#                                               str(self.Data)))
-#            
-#            if self._hasbounds:
-#                x.append(str(self.bounds.shape[-1]))
-#                string.append('%sBounds(%s) = %s' % (indent1, ', '.join(x),
-#                                                     str(self.bounds.Data)))
-#        else:
-#            x = [str(s) for s in self.shape]
-#            string.append('%sData(%s) = %s' % (indent1, ', '.join(x),
-#                                               str(self.Data)))
-#            
-#            if self._hasbounds:
-#                x.append(str(self.bounds.shape[-1]))
-#                string.append('%sBounds(%s) = %s' % (indent1, ', '.join(x),
-#                                                     str(self.bounds.Data)))
-#        #--- End: if
-#
-#        if self._simple_properties():
-#            string.append(self._dump_simple_properties(_level=_level+1))
-#
-#        string = '\n'.join(string)
-#       
-#        if display:
-#            print string
-#        else:
-#            return string
     #--- End: def
 
 #--- End: class
@@ -609,20 +564,19 @@ Return a string containing a full description of the coordinate.
 # ====================================================================
 
 class DimensionCoordinate(Coordinate):
-    '''
-
-A CF dimension coordinate construct.
+    '''A CF dimension coordinate construct.
 
 **Attributes**
 
-===============  ========  ===================================================
-Attribute        Type      Description
-===============  ========  ===================================================
-`!climatology`   ``bool``  Whether or not the bounds are intervals of
-                           climatological time. Presumed to be False if unset.
-===============  ========  ===================================================
+==============  ========  ============================================
+Attribute       Type      Description
+==============  ========  ============================================
+`!climatology`  ``bool``  Whether or not the bounds are intervals of
+                          climatological time. Presumed to be False if
+                          unset.
+==============  ========  ============================================
 
-'''
+    '''
 #    def _query_contain(self, value):
 #        '''#
 #
@@ -638,6 +592,8 @@ Attribute        Type      Description
 
 It assumed, but not checked, that the period has been set.
 
+.. seealso:: `roll`
+
 '''
 
         if self.direction():
@@ -1015,7 +971,8 @@ False
 #ppp
     # DimensionCoordinate method
     def get_bounds(self, create=False, insert=False, bound=None,
-                   cellsize=None, flt=0.5, copy=True):
+                   cellsize=None, flt=0.5, max=None, min=None,
+                   copy=True):
         '''Get or create the cell bounds.
     
 Either return its existing bounds or, if there are none, optionally
@@ -1159,6 +1116,20 @@ create bounds based on the coordinate array values.
              ``cellsize=6, flt=0.9`` will result in bounds of ``(2.6,
              -3.4), (0.6, -5.4), (-11.4, -17.4)``.
 
+    min: optional
+        Limit the created bounds to be no less than this number.
+
+          *Example:* 
+             To ensure that all latitude bounds are at least -90:
+             ``min=-90``.
+
+    max: optional
+        Limit the created bounds to be no more than this number.
+
+          *Example:* 
+             To ensure that all latitude bounds are at most 90:
+             ``max=90``.
+
     copy: `bool`, optional
         If False then the returned bounds are not independent of the
         existing bounds, if any, or those inserted, if *create* and
@@ -1269,6 +1240,17 @@ create bounds based on the coordinate array values.
     
                 dtype = type(bounds_1d[0])
     
+                if max is not None:
+                    if self.direction():
+                        bounds_1d[-1] = max
+                    else:
+                        bounds_1d[0] = max
+                if min is not None:
+                    if self.direction():
+                        bounds_1d[0] = min
+                    else:
+                        bounds_1d[-1] = min
+                        
             else:
                 # ----------------------------------------------------
                 # Create
@@ -1395,6 +1377,7 @@ None
                 return self
             else:
                 return self.copy()
+        #--- End: if
 
         shift %= self.size
 
@@ -1408,17 +1391,11 @@ None
                 return self.copy()
         elif period is None:
             raise ValueError(
-"Can't roll %s array by %s positions when no period has been set" %
-(shift, self.__class__.__name__))
+"Can't roll {} array by {} positions when no period has been set".format(
+    self.__class__.__name__, shift))
 
         direction = self.direction()
 
-#        if direction:
-#            mx = self.Data[-1]
-#        else:
-#            mx = self.Data[0]
-#            
-#        centre = (mx // period) * period
         centre = self._centre(period)
 
         c = super(DimensionCoordinate, self).roll(axis, shift, i=i)
