@@ -33,7 +33,7 @@ from .filearray import FileArray, _TempFileArray #, SharedMemoryArray, _shared_m
 _Units_conform = Units.conform
 
 _dtype_object = numpy_dtype(object)
-#fm = FREE_MEMORY()
+
 # --------------------------------------------------------------------
 # Set of partitions' temporary files
 #
@@ -239,14 +239,13 @@ If the partition contains a non-temporary file which is not referenced
 by any other partition then the file is closed.
 
         '''
-        self._decrement_file_counter()
-
         subarray = getattr(self, '_subarray', None)
-
+        
         # If the subarray is unique it will have 2 references to
         # it plus 1 within this method, making 3. If it has more
         # than 3 references to it then it is not unique.
-        if getrefcount is not None:            
+        if getrefcount is not None:
+            self._decrement_file_counter()
             if subarray is None or getrefcount(subarray) > 3:
                 return
         else:
@@ -261,19 +260,19 @@ by any other partition then the file is closed.
             # from disk.
             _remove_temporary_files(_partition_file)
 
-#        elif (numpy_ndarray is not None and 
-#              not isinstance(subarray, numpy_ndarray)):
-#            # This partition contains a non-temporary file which is
-#            # not referenced by any other partition, so close the
-#            # file.
-        elif (FileArray is not None and isinstance(subarray, FileArray)):
-            # This partition contains a non-temporary file which is
-            # not referenced by any other partition, so close the
-            # file if the count of partitions pointing to it is 0.
-            count = Partition.file_counter.get(subarray.file, None)
-            if count is not None and count <= 0:
-                subarray.close()
-            #--- End: if
+        else:
+            try:
+                if (FileArray is not None and isinstance(subarray, FileArray)):
+                    filename = getattr(subarray, 'file', None)
+                    if self.file_counter.get(filename, 999) <= 0:
+                        # This partition contains a non-temporary file
+                        # which is not referenced by any other
+                        # partitions, so close the file.
+                        subarray.close()
+            except:
+                # If we're here then it is likely that FileArray has been
+                # torn down, so just do nothing.                
+                pass
         #--- End: if
     #--- End: def
 
@@ -327,8 +326,11 @@ x.__str__() <==> str(x)
     #--- End: def
 
     def _add_to_file_counter(self, i):
-        '''Add i to the Partition.file_counter if self._subarray is an
-instance of FileArray and not a temporary FileArray.
+        '''Add i to the count of subarrays referencing the file of this
+partition's subarray.
+
+Only do this if self._subarray is an instance of FileArray, but not a
+temporary FileArray.
 
 :Parameters:
 
@@ -339,14 +341,28 @@ instance of FileArray and not a temporary FileArray.
     `None`
 
         '''
-        if hasattr(self, '_subarray'):
-            subarray = self._subarray
-            if (not isinstance(subarray, _TempFileArray) and
-                isinstance(subarray, FileArray)):
-                filename = subarray.file
-                if filename is not None:
-                    count = Partition.file_counter.get(filename, 0)
-                    Partition.file_counter[filename] = count + i
+        subarray = getattr(self, '_subarray', None)
+        if subarray is None:
+            return
+
+        try:
+            if (isinstance(subarray, FileArray) and
+                not isinstance(subarray, _TempFileArray)):
+                filename = getattr(subarray, 'file', None)
+                if filename is None:
+                    return
+
+                file_counter = self.file_counter
+                count = file_counter.get(filename, 0)
+                file_counter[filename] = count + i
+                if file_counter[filename] <= 0:
+                    # Remove the file from the dictionary if its count has
+                    # dropped to zero
+                    del file_counter[filename]
+        except:
+            # If we're here then it is likely that FileArray has been
+            # torn down, so just do nothing.
+            pass
     #--- End: def
 
     def _increment_file_counter(self):
@@ -754,69 +770,78 @@ values of the partition's `!_original` attribute and on the
             
         config = self.config
         if _debug:
-            print 'Partition.close: config =',config
+            print ' config =',config
 
         if config['serial']:
             # --------------------------------------------------------
             # SERIAL
             # --------------------------------------------------------
             if _debug:
-                print 'Partition.close: serial'
+                print '  serial'
+
             if config['readonly']:
+                if _debug:
+                    print '   readonly=True'
+                        
                 if originally_on_disk:
+                    if _debug:
+                        print '    subarray originally on disk'
+                        
                     if config.get('to_disk', False):
-                        # 1.1.1.1 Original subarray was on disk and we
-                        #         don't want to keep the current
-                        #         subarray
+                        # 1.1.1.1 The original subarray was on disk,
+                        #         we don't want to keep the current
+                        #         subarray in memory, and we are happy
+                        #         to discard any changes that may have
+                        #         been made to the subaray.
                         if _debug:
-                            print 'Partition.close: 1.1.1.1 revert'
+                            print '    1.1.1.1 revert'
                         self.revert()
                     elif FREE_MEMORY() <= FM_THRESHOLD():
-                        # 1.1.1.2 Original subarray was on disk but
-                        #         there is not enough memory to keep
-                        #         the current subarray
+                        # 1.1.1.2 The original subarray was on disk,
+                        #         we are happy to keep the current
+                        #         subarray in memory, but there is not
+                        #         enough free memory to do so.
                         if _debug:
-                            print 'Partition.close: 1.1.1.2 revert ({} <= {})'.format(FREE_MEMORY(), FM_THRESHOLD())
+                            print '    1.1.1.2 revert ({} <= {})'.format(FREE_MEMORY(), FM_THRESHOLD())
                         self.revert()
                     else:
-                        # 1.1.1.3 Original subarray was on disk and
-                        #         there is enough memory to keep the
-                        #         current subarray
+                        # 1.1.1.3 The original subarray was on disk
+                        #         and there is enough memory to keep
+                        #         the current subarray in memory
                         if (config['unique_subarray'] and 
                             isinstance(original_subarray, _TempFileArray)):
-                            # Original subarray was a temporary file
-                            # on disk which is not referenced by any
+                            # The original subarray was a temporary
+                            # file which is not referenced by any
                             # other partitions
                             _remove_temporary_files(original_subarray._partition_file)
 
+                        del self.masked      
                         if _debug:
-                            print 'Partition.close: 1.1.1.3 del masked ({} > {})'.format(FREE_MEMORY(), FM_THRESHOLD())
-                        del self.masked       
-                        pass
+                            print '    1.1.1.3 del masked ({} > {})'.format(FREE_MEMORY(), FM_THRESHOLD())
 
                 else:
                     if _debug:
-                        print 'Partition.close: subarray originally in memory'
+                        print '   subarray originally in memory'
                     if config.get('to_disk', False):
                         # 1.1.2.1 Original subarray was in memory and
                         #         we don't want to keep the current
                         #         subarray in memory
                         if _debug:
-                            print 'Partition.close: 1.1.2.1 to_disk'
+                            print '    1.1.2.1 to_disk'
                         self.to_disk(reopen=False)
                     elif FREE_MEMORY() <= FM_THRESHOLD():
                         # 1.1.2.2 Original subarray was in memory and
                         #         unique but there is not enough
                         #         memory to keep the current subarray
                         if _debug:
-                            print 'Partition.close: 1.1.2.2 to_disk'
+                            print '    1.1.2.2 to_disk'
                         self.to_disk(reopen=False)
                     else:
                         # 1.1.2.3 Original subarray was in memory and
                         #         unique and there is enough memory to
                         #         keep the current subarray in memory
                         if _debug:
-                            print 'Partition.close: 1.1.2.3 pass'
+                            print '    1.1.2.3 pass'
                         pass
             else:
                 # config['readonly'] is False
@@ -832,7 +857,8 @@ values of the partition's `!_original` attribute and on the
                             # other partitions
                             _remove_temporary_files(original_subarray._partition_file)
 
-                        if _debug: print 'Partition.close: 1.2.1.1 to_disk'
+                        if _debug:
+                            print '    1.2.1.1 to_disk'
                         self.to_disk(reopen=False)
                     elif FREE_MEMORY() <= FM_THRESHOLD():
                         # 1.2.1.2 Original subarray was on disk but
@@ -845,32 +871,36 @@ values of the partition's `!_original` attribute and on the
                             # other partitions
                             _remove_temporary_files(original_subarray._partition_file)
 
-                        if _debug: print 'Partition.close: 1.2.1.2 to_disk'
+                        if _debug:
+                            print '    1.2.1.2 to_disk'
                         self.to_disk(reopen=False)
                     else:
                         # 1.2.1.3 Original subarray was on disk and
                         #         there is enough memory to keep it
-                        if _debug: print 'Partition.close: 1.2.1.3 pass'
+                        if _debug:
+                            print '    1.2.1.3 pass'
                         del self.masked       
                         pass
                 else:
                     if config.get('to_disk', False):
                         # 1.2.2.1 Original subarray was in memory but
                         #         we don't want to keep it
-                        if _debug: print 'Partition.close: 1.2.2.1 to_disk'
+                        if _debug:
+                            print '    1.2.2.1 to_disk'
                         self.to_disk(reopen=False)
                     elif FREE_MEMORY() <= FM_THRESHOLD():
                         # 1.2.2.2 Original subarray was an in memory
                         #         but there is not enough memory to
                         #         keep it
-                        if _debug: print 'Partition.close: 1.2.2.2 to_disk'
+                        if _debug:
+                            print '    1.2.2.2 to_disk'
                         self.to_disk(reopen=False)
                     else:
                         # 1.2.2.3 Original subarray was in memory and
                         #         there is enough memory to keep it
-                        if _debug: print 'Partition.close: 1.2.2.3 pass'
+                        if _debug:
+                            print '    1.2.2.3 del masked'
                         del self.masked       
-                        pass
         else:
             if _debug: print 'Partition.close: parallel'
             # --------------------------------------------------------
