@@ -691,7 +691,6 @@ Evaluate the query operation for a given object.
             c = compound[0]._evaluate(x, attr)
             d = compound[1]._evaluate(x, attr)
             return self._bitwise_operator(c, d)
-        #--- End: if
 
         # Still here?
 
@@ -706,7 +705,8 @@ Evaluate the query operation for a given object.
         if operator == 'eq':
             if not self._exact:
                 if not isinstance(x, basestring):
-                    raise ValueError("Can't re.match on non-string")
+                    raise ValueError(
+                        "Can't re.match on a non-string: {}".format(x))
 
                 return bool(re_match(value, x))
             else:
@@ -716,7 +716,8 @@ Evaluate the query operation for a given object.
         if operator == 'ne':
             if not self._exact:
                 if not isinstance(x, basestring):
-                    raise ValueError("Can't re.match on non-string")
+                    raise ValueError(
+                        "Can't re.match on a non-string: {}".format(x))
 
                 return not re_match(value, x)
             else:
