@@ -1,21 +1,11 @@
-import unittest
-import os
-import netCDF4
-import numpy
 import datetime
-import platform
-import psutil
-import sys
-import cf
+import unittest
 
-if platform.python_version() < '2.7.0':
-    raise ValueError(
-        "Bad python version for unit tests. Requires python <= 2.7.0. Got %s." %
-        platform.python_version())
+import cf
 
 # Build the test suite from the tests found in the test files.
 testsuite_setup = unittest.TestSuite()
-testsuite_setup.addTests(unittest.TestLoader().discover('test', pattern='test_create_field.py'))
+testsuite_setup.addTests(unittest.TestLoader().discover('test', pattern='setup_create_field.py'))
 
 testsuite = unittest.TestSuite()
 testsuite.addTests(unittest.TestLoader().discover('test', pattern='test_*.py'))
@@ -40,6 +30,7 @@ if __name__ == '__main__':
     print ''
 
     cf.CHUNKSIZE(original_chunksize)
+
     run_test_suite_setup()
     run_test_suite()
 
