@@ -68,7 +68,7 @@ class MathTest(unittest.TestCase):
             return
 
         x_min = 0.0
-        x_max = 100.0
+        x_max = 359.0
         dx = 1.0
 
         x_1d = numpy.arange(x_min, x_max, dx)
@@ -84,6 +84,7 @@ class MathTest(unittest.TestCase):
             f = cf.Field()
             f.insert_dim(dim_x)
             f.insert_data(cf.Data(data_1d, 'm'), axes='X')
+            f.cyclic('X', period=360.0)
 
             g = f.derivative('X')
             self.assertTrue((g.array == 2.0).all())
@@ -149,7 +150,7 @@ class MathTest(unittest.TestCase):
         lat_size = lat_1d.size
 
         lon_min = 0.0
-        lon_max = 360.0
+        lon_max = 359.0
         dlon = 1.0
 
         lon_1d = numpy.arange(lon_min, lon_max, dlon)
@@ -179,11 +180,13 @@ class MathTest(unittest.TestCase):
             u.insert_dim(dim_x)
             u.insert_dim(dim_y)
             u.insert_data(cf.Data(u_2d, 'm/s'), axes=('X', 'Y'))
+            u.cyclic('X', period=360.0)
 
             v = cf.Field()
             v.insert_dim(dim_x)
             v.insert_dim(dim_y)
             v.insert_data(cf.Data(v_2d, 'm/s'), axes=('X', 'Y'))
+            v.cyclic('X', period=360.0)
             
             rv = cf.relative_vorticity(u, v, cyclic=True)
             self.assertTrue(numpy.allclose(rv.array, rv_array))
